pub fn decode_lint_envelope(
value: &Value,
options: LintDecodeOptions,
) -> Result<DecodedLintEnvelope, LintDecodeError>Expand description
Decode a lint envelope value and fail closed on contract violations.
pub fn decode_lint_envelope(
value: &Value,
options: LintDecodeOptions,
) -> Result<DecodedLintEnvelope, LintDecodeError>Decode a lint envelope value and fail closed on contract violations.