pub fn decode_lint_json(
text: &str,
options: LintDecodeOptions,
) -> Result<DecodedLintEnvelope, LintDecodeError>Expand description
Parse JSON text and fail closed on structural or semantic contract violations.
pub fn decode_lint_json(
text: &str,
options: LintDecodeOptions,
) -> Result<DecodedLintEnvelope, LintDecodeError>Parse JSON text and fail closed on structural or semantic contract violations.