pub fn try_load_runtime_extensions(
anchor: &Path,
) -> Result<RuntimeExtensions, PackageError>Expand description
Load the nearest project manifest plus any installed package manifests and merge the root project’s runtime extensions.
pub fn try_load_runtime_extensions(
anchor: &Path,
) -> Result<RuntimeExtensions, PackageError>Load the nearest project manifest plus any installed package manifests and merge the root project’s runtime extensions.