pub struct SkillLoaderInputs {
pub cli_dirs: Vec<PathBuf>,
pub source_path: Option<PathBuf>,
}Expand description
Inputs threaded in from the CLI layer. Anything we can compute from the environment or from the source path we compute internally; this struct captures only the stuff the user passed via flags.
Fields
cli_dirs: Vec<PathBuf>source_path: Option<PathBuf>Trait Implementations
Sourceimpl Clone for SkillLoaderInputs
impl Clone for SkillLoaderInputs
Sourcefn clone(&self) -> SkillLoaderInputs
fn clone(&self) -> SkillLoaderInputs
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SkillLoaderInputs
impl Debug for SkillLoaderInputs
Sourceimpl Default for SkillLoaderInputs
impl Default for SkillLoaderInputs
Sourcefn default() -> SkillLoaderInputs
fn default() -> SkillLoaderInputs