Structs
Functions
- cancel_
event_ in_ process - In-process entry point for
harn trigger cancel <event_id>. Used by integration tests to drive the cancel path without spawning theharnbinary. The binary entry calls the same internals viarun.
harn trigger cancel <event_id>. Used by
integration tests to drive the cancel path without spawning the harn
binary. The binary entry calls the same internals via run.