pub fn process_configuration_environment_value(
setup: &ProviderSetupManifest,
field: ConnectorSetupConfigurationField,
) -> Option<String>Expand description
Resolve one non-secret setup value only from names explicitly declared by the connector manifest. The value is returned to the setup adapter and must not be included in status, plan, event, or diagnostic output.